/** 
 @file main.js
 
 @brief This file contains implementation of User interface for the Sonos controller app.

 @author: mobile2DS

 @date: 31.1.2014
*/

var fLoading=false;
var oTimedEvent;
var predefinedUnduEvents = new Array(76, 65, 74, 83, 84, 85);
var groupNamePresets = new Array(32, 33, 34, 35, 36, 37, 38, 39, 84, 85);


Ext.define(
             'DSS.addon.SonosController',
             {
               extend : 'DSS.addon.Framework',
               fExpertMode:false,
               config : {
                   appName : 'Sonos Controller',
                   appId : 'sonos-controller-app',
                   appVersion : '0.8.2',
                   appIcon : 'default_icon.png'
               },
               
               getHelp : function() {
                   return Ext.create('Ext.Component', {
                       loader : {
                           url : 'locale/' + dss.staticDataModel.activeLanguage + '/help.html',
                           autoLoad : true,
                           disableCaching : false
                       }
                   });
               },

               discover : null,
               discoveryDialog : null,
               sNetworkIP : '', // dSS network IP        
               bIPFound : false,
               playersGrid : null,
               activitiesGrid : null,
               sPlayerIP : "", 
               oPresets : null,
               oMainActivities : null,
               oPlayers : null,
               mainAddonPanel : null,
               presetsGrid : null,
               
               getContent : function() {
                  var me = this;       
                  
                  var triggerPreset = Ext.create('DSS.addon.SelectPreset', {});
                  var selectRooms = Ext.create('DSS.addon.SelectRooms', {});
                  var whatToPlayPreset = Ext.create('DSS.addon.WhatToPlay', {parent:'Preset'});
                  var whatToPlayActivity = Ext.create('DSS.addon.WhatToPlay', {parent:'Activity'});

                  me.discover = Ext.create('DSS.component.Editor', { title : _('Manually enter IP address'),
                                                                     saveTitle : _('Save'),
                                                                     staticControls : [{
                                                                       type : 'custom',                               
                                                                       id : 'discoverIP',
                                                                       control : Ext.create('DSS.addon.ManualIP', {})
                                                                     }]
                                                                   });
                                                                   
                  /* 
                    Hiding audio scenes from Activities trigger control
                  */
                  var zones = dss.staticDataModel.getZoneArray();
                  if (zones != null) {
                    for (var iIndex=0;iIndex<zones.length;iIndex++) {
                      var oGroup = dss.staticDataModel.getGroupForZone(zones[iIndex].ZoneID);
                      if (oGroup != null) {
                        for (var xIndex=0;xIndex<oGroup.length;xIndex++) {
                          if (oGroup[xIndex].group == 4) {
                            oGroup[xIndex].reachable = false; // set flag to false so it would not be visible inside control
                            break;
                          }
                        }
                      }
                      
                      if (Ext.data.StoreManager.lookup('triggerConfigurator_groupStore_' + zones[iIndex].ZoneID) == null) {        
                        Ext.create('Ext.data.Store', {
                                    storeId : 'triggerConfigurator_groupStore_' + zones[iIndex].ZoneID,
                                    fields : [ 'group', 'name', 'icon', 'reachable' ],
                                    proxy : {
                                        type : 'memory',
                                        reader : {
                                            type : 'json',
                                            root : 'items'
                                        }
                                    }
                                });
                        Ext.data.StoreManager.lookup('triggerConfigurator_groupStore_' + zones[iIndex].ZoneID).add(oGroup);
                      }
                    }
                  } 
                  
                  /* Remove undo call from trigger*/  
                  /*
                  var Aktionen = [{
                                      name : dss.staticDataModel.getNameForScene(0, 0, 65),
                                      id : 65,
                                      next : false,
                                      icon : dss.staticDataModel.getImagePathForScene(0, 0, 65)
                                  }, {
                                    name : dss.staticDataModel.getNameForState('fire', 'active'),
                                      id : 'fire_active',
                                      next : false,
                                      icon : dss.staticDataModel.getImagePathForState('fire', 'active')
                                  }, {
                                      name : dss.staticDataModel.getNameForScene(0, 0, 74),
                                      id : 74,
                                      next : false,
                                      icon : dss.staticDataModel.getImagePathForScene(0, 0, 74)
                                  }, {
                                      name : dss.staticDataModel.getNameForScene(0, 0, 83),
                                      id : 83,
                                      next : false,
                                      icon : dss.staticDataModel.getImagePathForScene(0, 0, 83)
                                  }, {
                                      name : dss.staticDataModel.getNameForScene(0, 0, 84),
                                      id : 84,
                                      next : false,
                                      icon : dss.staticDataModel.getImagePathForScene(0, 0, 84)
                                  }, {
                                      name : dss.staticDataModel.getNameForScene(0, 0, 85),
                                      id : 85,
                                      next : false,
                                      icon : dss.staticDataModel.getImagePathForScene(0, 0, 85)
                                  } ];
                  Ext.create('Ext.data.Store', {
                      storeId : 'triggerConfigurator_securityStore',
                      fields : [ 'id', 'name', 'next', 'icon' ],
                      proxy : {
                          type : 'memory',
                          reader : {
                              type : 'json',
                              root : 'items'
                          }
                      }
                  });
                  Ext.data.StoreManager.lookup('triggerConfigurator_securityStore').add(Aktionen);
                  */  
                                                                   
                  me.discover.width = 580;
                  me.discover.on({
                         'save' : function(oValue) {
                            me.discoveryDialog = new Ext.LoadMask(Ext.getBody(), {msg:_('Discovering Sonos devices. Please wait...')});
                            me.discoveryDialog.show();
                            dss.raiseEvent('sonos-controller.startdiscovery', {
                                      actions : 'discover',
                                      value : Ext.JSON.encode(oValue)
                                  });

                             var iSubscriptID = Math.floor(Math.random() * 100000000000);
                             dss.ajaxSyncRequest('/json/event/subscribe', {
                                 subscriptionID : iSubscriptID,
                                 name : 'sonos-discover-finished'
                             });

                             dss.ajaxAssyncRequestWithoutAnswer('/json/event/get', {
                                 subscriptionID : iSubscriptID,
                                 timeout : 10*1000
                                }, function(sValue) {
                                 me.loadParameter(me.playersGrid);
                                 if (me.activitiesGrid != null)
                                   me.loadParameterActivity(me.activitiesGrid);
                                   
                                 me.discoveryDialog.hide();
                                 
                                 var oValue=JSON.parse(sValue);
                                 var sMessage = _("Discovery failed!");
                                 if (oValue.result.events[0] != null && oValue.result.events[0].properties.ip != "")
                                   sMessage = _("Discovery successfully completed.");
                                 
                                 Ext.MessageBox.alert(_('Discovery'), sMessage, null);
                                 
                                 
                                 dss.ajaxAssyncRequestWithoutAnswer('/json/event/unsubscribe', {
                                     subscriptionID : iSubscriptID,
                                     name : 'sonos-discover-finished'
                                 });
                             });
                             }
                             
                     });                                                                    
                    
                  var oConfig={
                          inactiveField:'notDiscovered',
                          defaultSortCol:'name',
                          disabledProperty:'disabled',
                          inactiveDisabledProperty:'checkboxShouldBeEnabled',
                          storeConfig: {
                              storeId : 'pushStore',
                              fields : [ {name : 'id'}, 
                                         {name:'disabled'}, {name:'notDiscovered'},
                                         {name:'sonosRoom', sortType:'asUCText'}, 
                                         {name:'playersList', sortType:'asUCText'}, 
                                         {name:'playersListDisplay', sortType:'asUCText'}, 
                                         {name:'playersListSerial', sortType:'asUCText'}, 
                                         {name:'roomID', sortType:'asUCText'}, 
                                         {name:'roomName', sortType:'asUCText'}, 
                                         {name:'ipAddress', sortType:'asUCText'} 
                                       ]
                          },
                          multiselect:true,
                          columns: [
                          {    
                              header : _('Active'),
                              dataIndex : 'disabled',
                              resizable : false,
                              xtype: 'disabledcolumn', 
                              width : 50
                          },{
                              header : _('Sonos Room'),
                              dataIndex : 'sonosRoom',
                              xtype: 'textcolumn', 
                              width : 300
                          },{
                              header : _('Players'),
                              dataIndex : 'playersListDisplay',
                              xtype: 'textcolumn', 
                              width : 150,
                          },{
                              header : _('Room'),
                              dataIndex : 'roomName',
                              xtype:'textcolumn',
                              flex : 1
                          },{
                              header : _('Serial Number'),
                              dataIndex : 'playersListSerial',
                              xtype: 'textcolumn', 
                              width : 150,
                          },{
                              header : _('IP Address'),
                              dataIndex : 'ipAddress',
                              xtype: 'textcolumn', 
                              width : 150,
                          }],     
                          buttonText: {
                            editButton: _('Assign Room'),
                            disableButton : _('Deactivate Player'),
                            enableButton:_('Activate Player'),
                            /*deleteButton: _('Delete Player'),*/
                          },
                          customButtons: [
                                         {text:_('Autodiscovery'), 
                                          iconCls:'icon-discovery',
                                          handler:function(grid,entry){
                                               me.discoveryDialog = new Ext.LoadMask(Ext.getBody(), {msg:_('Auto discovering Sonos devices. Please wait...')});
                                               me.discoveryDialog.show();

                                               var sNetworkIP = "";
                                               var sResponseIP = dss.ajaxSyncRequest('/cgi-bin/netinfo.sh', {});
                                               if (sResponseIP != "") {
                                                 var dssNet = JSON.parse(sResponseIP);
                                                 if (dssNet != null && dssNet.data != null & dssNet.data.ip != null)
                                                   sNetworkIP = dssNet.data.ip;
                                               }
                                               var result = Ext.JSON.decode(dss.ajaxSyncRequest('/json/property/query', {
                                                                                                  'query' : '/scripts/sonos-controller/sonos-players/*(*)/*(*)/*(*)/*(*)'
                                                                                               }));                                              
                                               var arrayTestIP = new Array();
                                               oResultObject=dss.parsePropertyQueryAnswer(result,[{name:'ipAddress',type:'simple'}]);    
                                               if (oResultObject!=null) {
                                                 for (var iIndex=0;iIndex<oResultObject.length;iIndex++) {
                                                  arrayTestIP.push({inList:1, ipAddress:oResultObject[iIndex].ipAddress});
                                                 }
                                               }
                                               if (sNetworkIP != "")
                                                 arrayTestIP.push({inList:0, ipAddress:sNetworkIP});
                                              
                                               if (arrayTestIP.length > 0) {
                                                 dss.raiseEvent('sonos-controller.startdiscovery', {
                                                       actions : 'AutoDiscover',
                                                       value : Ext.JSON.encode(arrayTestIP)});
                                                       
                                                 var iSubscriptID = Math.floor(Math.random() * 100000000000);
                                                 dss.ajaxSyncRequest('/json/event/subscribe', {
                                                     subscriptionID : iSubscriptID,
                                                     name : 'sonos-autodiscover-finished'
                                                 });

                                                 dss.ajaxAssyncRequestWithoutAnswer('/json/event/get', {
                                                     subscriptionID : iSubscriptID,
                                                     timeout : 120*1000
                                                 }, function(sValue) {
                                                     dss.ajaxAssyncRequestWithoutAnswer('/json/event/unsubscribe', {
                                                         subscriptionID : iSubscriptID,
                                                         name : 'sonos-autodiscover-finished'
                                                     });

                                                     var sMessage = _("Autodiscovery failed!");
                                                     if (sValue != null) {
                                                       me.loadParameter(me.playersGrid);
                                                       if (me.activitiesGrid != null)
                                                         me.loadParameterActivity(me.activitiesGrid);
                                                       
                                                       me.discoveryDialog.hide();
                                                       
                                                       var oValue=JSON.parse(sValue);
                                                       
                                                       if (oValue.result.events[0] != null && oValue.result.events[0].properties.ip != "")
                                                         sMessage = _("Autodiscovery successfully completed.");
                                                     }
                                                     
                                                     Ext.MessageBox.alert(_('Autodiscovery info'), sMessage, null);
                                                       
                                                 });  
                                              }
                                              else {
                                                Ext.MessageBox.alert(_('Autodiscovery info'), _('No network info available for Autodiscovery, please use Manual enter IP address button.'), null);
                                              }
                                           
                                           }}, 
                                           {text:_('Manually enter IP address'), 
                                            iconCls:'icon-manual-discovery',
                                            handler:function(grid,entry){
                                              me.discover.setValues({discoverIP: ""});
                                              me.discover.show();
                                             }
                                           },
/*
                                           {text:_('Delete Player'), 
                                            iconCls:'icon-delete-action',
                                            handler:function(grid,entry){
                                             }
                                           }
*/                                           
                                          ],
                          editorConfig:{
                              title : _('Player Info'),
                              staticControls : [{ type : 'hidden', id : 'id'}, { type : 'hidden', id : 'roomID'},
                               {                              
                                type : 'custom',                               
                                id : 'sonosRoom',
                                control : Ext.create('DSS.component.SonosRoomLabel', {})},
                               {                              
                                type : 'custom',                               
                                id : 'playersList',
                                control : Ext.create('DSS.component.SonosDeviceLabel', {})},
                              ],
                          },
                          listeners: {
                              'loadDataStore':function (grid){
                                  me.loadParameter(grid);
                                  me.playersGrid = grid;
                              },
                              'saveEntry':function (grid,values){    
                                  dss.raiseEvent('sonos-controller.save', {
                                      actions : 'assignRoom',
                                      value : Ext.JSON.encode(values)
                                  })
                                  me.waitAndReload(grid);
                              },  
                              'deleteEntry':function (grid,entry){
/*                               
                               var idVal;
                               if (entry.get!=null) {
                                idVal=entry.get('id');
                               } else {
                                idVal=[];
                                for (var iIndex=0;iIndex<entry.length;iIndex++) 
                                 if (entry[iIndex]!=null)
                                  idVal.push(entry[iIndex].get('id'));
                               }
                                  dss.raiseEvent('sonos-controller.save', {
                                      actions : 'deleteActivity',
                                      id : Ext.JSON.encode(idVal)
                                  })
                                  me.waitAndReload(grid);
*/                             
                              },
                              'disableEntry':function (grid,entry){
                                  var idVal;
                                  if (entry.get!=null) {
                                   idVal=entry.get('id');
                                  } 
                                  else {
                                   idVal=[];
                                   for (var iIndex=0;iIndex<entry.length;iIndex++) 
                                    if (entry[iIndex]!=null)
                                     idVal.push(entry[iIndex].get('id'));
                                  }
                                  dss.raiseEvent('sonos-controller.save', {
                                      actions : 'disablePlayer',
                                      id : Ext.JSON.encode(idVal)
                                  })
                                  me.waitAndReload(grid);
                              },
                              'enableEntry':function (grid,entry){
                                  var idVal;
                                  if (entry.get!=null) {
                                   idVal=entry.get('id');
                                  } else {
                                   idVal=[];
                                   for (var iIndex=0;iIndex<entry.length;iIndex++) 
                                    if (entry[iIndex]!=null)
                                     idVal.push(entry[iIndex].get('id'));
                                  }
                                  dss.raiseEvent('sonos-controller.save', {
                                      actions : 'enablePlayer',
                                      id : Ext.JSON.encode(idVal)
                                  })
                                  me.waitAndReload(grid);
                               },                                             
                          }
                  };
                          
                  var oConfigPR={
                          inactiveField:'predefined',
                          grouperField: 'grouping',
                          defaultSortCol:'predefined',
                          disabledProperty:'disabled',
                          inactiveDisabledProperty:'checkboxShouldBeEnabled',
                          storeConfig: {
                              storeId : 'pushStorePr',
                              fields : [ {name: 'id'}, 
                                         {name: 'disabled', sortType: 'asBoolean'},  {name:'predefined'},
                                         {name: 'whatToPlay'}, {name: 'triggerPreset'},
                                         {name: 'presetID', sortType:'asInt'}, 
                                         {name: 'presetName', sortType:'asPreset'}, 
                                         {name: 'whatToPlayInfo', sortType:'asUCText'}, 
                                         {name: 'audioName', sortType:'asInt'},
                                         {name: 'roomID', sortType:'asUCText'}, 
                                         {name: 'roomName', sortType:'asUCText'}, 
                                         {name: 'setVolume', sortType:'asBoolean'}, 
                                         {name: 'volume', sortType:'asInt'},
                                         {name: 'volumeValue', sortType:'asUCText'},
                                         {name: 'grouping',  sortType: 'asUCText'},
                                       ]
                          },
                          multiselect:true,
                          columns: [
                          {    
                              header : _('Active'),
                              dataIndex : 'disabled',
                              resizable : false,
                              xtype: 'disabledcolumn', 
                              width : 50
                          },{
                              header : _('Name'),
                              dataIndex : 'audioName',
                              xtype:'textcolumn',
                              width : 250
                          },{
                              header : _('Trigger Preset'),
                              dataIndex : 'presetName',//presetName
                              xtype: 'textcolumn', 
                              width : 200
                          },{
                              header : _('What To Play'),
                              dataIndex : 'whatToPlayInfo',
                              xtype: 'textcolumn', 
                              width : 400
                          },{
                              header : _('Volume'),
                              dataIndex : 'volumeValue',
                              xtype:'textcolumn',
                              flex : 1
                          }],     
                          buttonText: {
                              newButton: _('New Preset'),
                              editButton: _('Edit Preset'),
                              deleteButton: _('Delete Preset'),
                              disableButton : _('Deactivate Preset'),
                              enableButton:_('Activate Preset'),
                              testButton:_('Test Preset'),
                          },
                          editorConfig:{
                              title : _('Manage Room Preset'),
                              defaultTabOnEdit : 'whatToPlay',
                              staticControls : [{ type : 'hidden', id : 'id'}, 
                                                { type : 'hidden', id : 'roomID'},
                                                { type : 'hidden', id : 'presetID'},
                                 {type : 'text',
                                  label : _('Action name'),
                                  id : 'audioName'}
                                 ], 
                              tabControls : [{tabLabel : _('Trigger'),
                                              tabDescription : _('Select the room and preset that triggers the music/command.'),
                                              content : [{type : 'custom',
                                                          id : 'triggerPreset',
                                                          control: triggerPreset,//Ext.create('DSS.addon.SelectPreset', {})
                                                         }]
                                             },
                                             {tabLabel : _('What To Play'),
                                              tabDescription : _('Select the music that will be played/executed.'),
                                              content : [{type : 'custom',
                                                          id : 'whatToPlay',
                                                          control: whatToPlayPreset,//Ext.create('DSS.addon.WhatToPlay', {parent:'Preset'})
                                                         }]
                                             }],                               
                          },
                          listeners: {
                              'loadDataStore':function (grid){
                                  me.loadParameterPreset(grid);
                                  me.presetsGrid = grid;
                              },
                              'saveEntry':function (grid,values){    
                                  var sAudioSceneName = unescape(values.audioName);
                                  Ext.Ajax.request({url: "/json/zone/sceneSetName?id="+values.triggerPreset.roomID+"&groupID=4&sceneNumber="+values.triggerPreset.presetID+"&newName="+sAudioSceneName});
                                  dss.raiseEvent('sonos-controller.save', {
                                      actions : 'storePreset',
                                      value : Ext.JSON.encode(values)
                                  });
                                  me.waitAndReloadPreset(grid);
                              },  
                              'deleteEntry':function (grid,entry) {
                                  var idVal;
                                  if (entry.get!=null) {
                                    idVal=entry.get('id');
                                    // deleting audio scene name
                                    Ext.Ajax.request({url: "/json/zone/sceneSetName?id="+entry.get("roomID")+"&groupID=4&sceneNumber="+entry.get("presetID")+"&newName="});
                                  } else {
                                   idVal=[];
                                   for (var iIndex=0;iIndex<entry.length;iIndex++) 
                                    if (entry[iIndex]!=null) {
                                     idVal.push(entry[iIndex].get('id'));
                                     Ext.Ajax.request({url: "/json/zone/sceneSetName?id="+entry[iIndex].get("roomID")+"&groupID=4&sceneNumber="+entry[iIndex].get("presetID")+"&newName="});
                                    }
                                  }
                                  dss.raiseEvent('sonos-controller.save', {
                                      actions : 'deletePreset',
                                      id : Ext.JSON.encode(idVal)
                                  })
                                  me.waitAndReloadPreset(grid);
                              },
                              'disableEntry':function (grid,entry){
                                  var idVal;
                                  if (entry.get!=null) {
                                   idVal=entry.get('id');
                                  } 
                                  else {
                                   idVal=[];
                                   for (var iIndex=0;iIndex<entry.length;iIndex++) 
                                    if (entry[iIndex]!=null)
                                     idVal.push(entry[iIndex].get('id'));
                                  }
                                  dss.raiseEvent('sonos-controller.save', {
                                      actions : 'disablePreset',
                                      id : Ext.JSON.encode(idVal)
                                  })
                                  me.waitAndReloadPreset(grid);
                              },
                              'enableEntry':function (grid,entry){
                                  var idVal;
                                  if (entry.get!=null) {
                                   idVal=entry.get('id');
                                  } else {
                                   idVal=[];
                                   for (var iIndex=0;iIndex<entry.length;iIndex++) 
                                    if (entry[iIndex]!=null)
                                     idVal.push(entry[iIndex].get('id'));
                                  }
                                  dss.raiseEvent('sonos-controller.save', {
                                      actions : 'enablePreset',
                                      id : Ext.JSON.encode(idVal)
                                  })
                                  me.waitAndReloadPreset(grid);
                               },
                               'testEntry':function (grid,entry){
                                   dss.ajaxAssyncRequestWithoutAnswer("/json/event/raise",
                                           {name:'sonos_execute', 
                                            parameter:"path=/scripts/sonos-controller/sonos-presets/" + entry.get('id')+";groupID=4"});                       
                               }
                             }
                  };
                  
                  var oConfigAct={
                          defaultSortCol:'roomName',
                          disabledProperty:'disabled',
                          inactiveDisabledProperty:'checkboxShouldBeEnabled',
                          storeConfig: {
                              storeId : 'pushStoreAct',
                              fields : [ {name: 'id'}, {name: 'whatToPlay'}, {name: 'selectedRoom'},
                                         {name: 'disabled', sortType: 'asBoolean'},
                                         {name: 'actionTrigger'},
                                         {name: 'triggers', sortType: 'asTrigger' },
                                         {name: 'whatToPlayInfo', sortType:'asUCText'}, 
                                         {name: 'disabled', sortType:'asBoolean'}, 
                                         {name: 'activityID', sortType:'asInt'}, 
                                         {name: 'activityName', sortType:'asUCText'}, 
                                         {name: 'volume', sortType:'asInt'},
                                         {name: 'volumeValue', sortType:'asUCText'},
                                         {name: 'execRoomsName', sortType:'asUCText'},
                                       ]
                          },
                          multiselect:true,
                          columns: [
                          {    
                              header : _('Active'),
                              dataIndex : 'disabled',
                              resizable : false,
                              xtype: 'disabledcolumn', 
                              width : 50
                          },
                          {
                              header: _('Trigger'),
                              dataIndex: 'triggers',
                              xtype: 'triggercolumn',
                              maintainFlex: true,
                              flex: 3,
                          },{
                              header : _('What To Play'),
                              dataIndex : 'whatToPlayInfo',
                              xtype: 'textcolumn', 
                              width : 400
                          },{
                              header : _('Where To Play'),
                              dataIndex : 'execRoomsName',
                              xtype: 'textcolumn', 
                              width : 300,
                          },{
                              header : _('Volume'),
                              dataIndex : 'volumeValue',
                              xtype:'textcolumn',
                              flex : 1
                          }],     
                          buttonText: {
                              newButton: _('New Activity'),
                              editButton: _('Edit Activity'),
                              deleteButton: _('Delete Activity'),
                              disableButton : _('Deactivate Activity'),
                              enableButton:_('Activate Activity'),
                              testButton:_('Test Activity'),
                          },
                          editorConfig:{
                              title : _('Manage Activity'),
                              staticControls : [{ type : 'hidden', id : 'id'}, 
                                                { type : 'hidden', id : 'execRoomID'},
                                                { type : 'hidden', id : 'activityID'},
                                               ],    
                              tabControls : [ 
                                {
                                  tabLabel : _('Trigger'),
                                  tabDescription : _('Choose the triggering activity for the message. You can choose more than one activity as trigger.'),
                                  content : [{ type : 'TriggerConfigurator',
                                               id : 'triggers',
                                               flex : true
                                               }]}, 
                                {              
                                  tabLabel : _('What To Play'),
                                  tabDescription : _('Select the music/command that will be played/executed.'),
                                  content : [{ type : 'custom',
                                               id : 'whatToPlay',
                                               control: whatToPlayActivity,// Ext.create('DSS.addon.WhatToPlay', {parent:'Activity'})
                                             } 
                                            ]
                                 }, 
                                 {
                                  tabLabel : _('Where To Play'),
                                  tabDescription : _('Select the rooms where music should be played.'),
                                  content : [{type : 'custom',
                                              id : 'selectedRoom',
                                              control: selectRooms,
                                              }]
                                } 
                                ], 
                          },
                          listeners: {
                              'loadDataStore':function (grid){
                                  me.loadParameterActivity(grid);
                                  me.activitiesGrid = grid;
                              },
                              'saveEntry':function (grid,values){    
                                  dss.raiseEvent('sonos-controller.save', {
                                      actions : 'storeActivity',
                                      value : Ext.JSON.encode(values)
                                  })
                                  me.waitAndReloadActivities(grid);
                              },  
                              'deleteEntry':function (grid,entry) {
                                  var idVal;
                                  if (entry.get!=null) {
                                   idVal=entry.get('id');
                                  } else {
                                   idVal=[];
                                   for (var iIndex=0;iIndex<entry.length;iIndex++) 
                                    if (entry[iIndex]!=null)
                                     idVal.push(entry[iIndex].get('id'));
                                  }
                                  dss.raiseEvent('sonos-controller.save', {
                                      actions : 'deleteActivity',
                                      id : Ext.JSON.encode(idVal)
                                  })
                                  me.waitAndReloadActivities(grid);
                              },
                              'disableEntry':function (grid,entry){
                                  var idVal;
                                  if (entry.get!=null) {
                                   idVal=entry.get('id');
                                  } 
                                  else {
                                   idVal=[];
                                   for (var iIndex=0;iIndex<entry.length;iIndex++) 
                                    if (entry[iIndex]!=null)
                                     idVal.push(entry[iIndex].get('id'));
                                  }
                                  dss.raiseEvent('sonos-controller.save', {
                                      actions : 'disableActivity',
                                      id : Ext.JSON.encode(idVal)
                                  })
                                  me.waitAndReloadActivities(grid);
                              },
                              'enableEntry':function (grid,entry){
                                  var idVal;
                                  if (entry.get!=null) {
                                   idVal=entry.get('id');
                                  } else {
                                   idVal=[];
                                   for (var iIndex=0;iIndex<entry.length;iIndex++) 
                                    if (entry[iIndex]!=null)
                                     idVal.push(entry[iIndex].get('id'));
                                  }
                                  dss.raiseEvent('sonos-controller.save', {
                                      actions : 'enableActivity',
                                      id : Ext.JSON.encode(idVal)
                                  })
                                  me.waitAndReloadActivities(grid);
                               },   
                               'testEntry':function (grid,entry){
                                   var infoDialog = new Ext.LoadMask(Ext.getBody(), {msg:_('Testing activity in progress. Please wait ... ')});
                                   infoDialog.show();

                                   dss.ajaxAssyncRequestWithoutAnswer('/json/event/raise',
                                            {name:'sonos_execute', 
                                             parameter:"path=/scripts/sonos-controller/sonos-activities/" + entry.get('id')+";groupID=0;sceneID=-1"}
                                   ); 
                                   
                                   var iSubscriptID = Math.floor(Math.random() * 100000000000);
                                   dss.ajaxSyncRequest("/json/event/subscribe",
                                           {name:'sonos-test-activity-finished', 
                                            subscriptionID : iSubscriptID} 
                                   );     
                                   
                                   dss.ajaxAssyncRequestWithoutAnswer('/json/event/get', {
                                              subscriptionID : iSubscriptID,
                                              timeout : 15000
                                            }, 
                                            function(sValue) {
                                              infoDialog.hide();
                                              dss.ajaxAssyncRequestWithoutAnswer('/json/event/unsubscribe', {
                                                    subscriptionID : iSubscriptID,
                                                    name : 'sonos-test-activity-finished'
                                              });
                                            }
                                   );     

                               }

                          }
                  };

                  var oMainPresets = Ext.create('DSS.gridPanel', oConfigPR);
                  me.oPresets = Ext.create('Ext.panel.Panel', { title : _('Room Presets'), layout : 'fit', items : [ oMainPresets ]});
                  var oMainActivities = Ext.create('DSS.gridPanel', oConfigAct);
                  me.oActivities = Ext.create('Ext.panel.Panel', { title : _('Global Activities'), layout : 'fit', items : [ oMainActivities ]});
                  var oMainGrid = Ext.create('DSS.gridPanel', oConfig);
                  me.oPlayers = Ext.create('Ext.panel.Panel', { title : _('Players'), layout : 'fit', items : [ oMainGrid ]});
                  oMainGrid.editorWindow.setWidth(420); 

                  // Catching cancel button on edit dialog for activities
                  var oEditorAct=oMainActivities.editorWindow;
                  oMainActivities.editorWindow.buttonCancel.setHandler(function (){
                    var infoDialog=oEditorAct.editControls.whatToPlay.infoDialog;
                    if (infoDialog != null)
                      infoDialog.hide();
                    if (oEditorAct.editControls.whatToPlay.testPlayStopSubscriptID != null &&
                        oEditorAct.editControls.whatToPlay.testPlayStopSubscriptID > 0) {
                    
                      dss.ajaxAssyncRequestWithoutAnswer('/json/event/unsubscribe', {
                          subscriptionID : oEditorAct.editControls.whatToPlay.testPlayStopSubscriptID,
                          name : 'sonos-controller-test-play-stopped'
                      });
                    }
                    
                    var t2s = oEditorAct.editControls.whatToPlay.t2sCreatedObj;
                    if (t2s != null) {
                      // we must delete created text2speech files that are not saved and used
                      if (t2s.guid != "" && t2s.guid != t2s.originalGuid) {
                        dss.raiseEvent('sonos-controller.testPlay', {
                                        actions : 'delete',
                                        value : Ext.JSON.encode(t2s.guid)
                                    });
                      }
                    }
                    
                    oEditorAct.fireEvent('cancel');
                    oEditorAct.hide();
                  });

                  // Catching cancel button on edit dialog for preset
                  var oEditorPreset=oMainPresets.editorWindow;
                  oMainPresets.editorWindow.buttonCancel.setHandler(function (){
                    var infoDialog=oEditorPreset.editControls.whatToPlay.infoDialog;
                    if (infoDialog != null)
                      infoDialog.hide();
                    oEditorPreset.fireEvent('cancel');
                    oEditorPreset.hide();
                  });
                  
                  me.mainAddonPanel = Ext.create('Ext.tab.Panel', {
                        layout : 'fit',
                        cls:'generalTab',
                        items : [me.oPresets, me.oActivities, me.oPlayers] //,    items : [ me.oPresets, me.oActivities, me.oPlayers ] 
                  });
                  me.setupTabs();
                  return me.mainAddonPanel; 
               },
               
               setupTabs : function() {
                 var me = this;
                 if (me.mainAddonPanel != null) {
                   me.oPresets.setDisabled(false);
                   me.oActivities.setDisabled(false);
                   if (me.bDisableTabs) {
                     me.oPresets.setDisabled(true);
                     me.oActivities.setDisabled(true);
                     me.mainAddonPanel.setActiveTab(me.oPlayers);
                   }
                 }
               },                           
               
               loadParameter : function(grid) {
                grid.setStatus(_('Loading ...'));
                    var me = this;
                   var sString = dss.ajaxSyncRequest('/json/property/query', {
                       'query' : '/scripts/sonos-controller/sonos-players/*(*)/*(*)/*(*)/*(*)'
                   });
                   var result = Ext.JSON.decode(sString);
                   
                   oResultObject=dss.parsePropertyQueryAnswer(result,[{name:'id',type:'simple'},
                                                                      {name:'ipAddress',type:'simple'},
                                                                      {name:'sonosRoom',type:'simple'},
                                                                      {name:'playersList',type:'simple'},
                                                                      {name:'playersListSerial',type:'simple'},
                                                                      {name:'disabled', type:'simple'},
                                                                      {name:'deviceID',type:'simple'},
                                                                      {name:'notDiscovered',type:'simple'},
                                                                      {name:'playersListIPSlaves',type:'simple'},
                                                                      {name:'roomID',type:'simple'}]); 
                   this.bDisableTabs = true;   
                   me.sPlayerIP = "";
                   if (oResultObject!=null) {
                       for (var iIndex=0;iIndex<oResultObject.length;iIndex++) {
                           oResultObject[iIndex].disabled = JSON.parse(oResultObject[iIndex].disabled);
                           oResultObject[iIndex].notDiscovered = JSON.parse(oResultObject[iIndex].notDiscovered);
                           oResultObject[iIndex].roomName= "-";
                           oResultObject[iIndex].roomID = (parseInt("" + oResultObject[iIndex].roomID,10));
                           if (oResultObject[iIndex].roomID > 0) {
                              this.bDisableTabs = false;
                             oResultObject[iIndex].roomName= dss.staticDataModel.getNameForZone(oResultObject[iIndex].roomID);
                           }
                           if(oResultObject[iIndex].playersList != null)
                             oResultObject[iIndex].playersListDisplay = oResultObject[iIndex].playersList.replace("%2C%20", ", ");
                           if(oResultObject[iIndex].playersListSerial != null)
                             oResultObject[iIndex].playersListSerial = oResultObject[iIndex].playersListSerial.replace("%2C%20", ", ");
                           if(oResultObject[iIndex].playersListIPSlaves != null && oResultObject[iIndex].playersListIPSlaves != "")
                             oResultObject[iIndex].ipAddress += ", " + oResultObject[iIndex].playersListIPSlaves.replace("%2C%20", " "); 

                           if (me.sPlayerIP == "" && !oResultObject[iIndex].disabled && oResultObject[iIndex].ipAddress != "")
                             me.sPlayerIP = oResultObject[iIndex].ipAddress;
                       }
                       // reloading sonos playlists
                       grid.loadParameter(oResultObject); 
                   }
                   this.setupTabs();
                   grid.setStatus(_('Ready'));
               },
               waitAndReload : function(grid) {            
                    grid.setStatus(_('Saving ...'));
                       var me = this;
                       
                       var iSubscriptID = Math.floor(Math.random() * 100000000000);
                       dss.ajaxSyncRequest('/json/event/subscribe', {
                           subscriptionID : iSubscriptID,
                           name : 'sonos-controller-saved'
                       });
                       dss.ajaxAssyncRequestWithoutAnswer('/json/event/get', {
                           subscriptionID : iSubscriptID,
                           timeout : 120 * 1000
                       }, function(sValue) {
                           var oValue=JSON.parse(sValue);
                           if (oValue.result.events[0] != null && oValue.result.events[0].properties.nNewRoomID != "-1") {
                             Ext.Ajax.request({url: "/json/zone/sceneSetName?id="+oValue.result.events[0].properties.nNewRoomID+"&groupID=4&sceneNumber=5&newName="+_('Play')});
                             Ext.Ajax.request({url: "/json/zone/sceneSetName?id="+oValue.result.events[0].properties.nNewRoomID+"&groupID=4&sceneNumber=0&newName="+_('Pause')});
                           } 
                        
                           me.loadParameter(grid);
                           if (me.presetsGrid != null) {
                             me.loadParameterPreset(me.presetsGrid);
                           }
                           if (me.activitiesGrid != null) {
                             me.loadParameterActivity(me.activitiesGrid);
                           }
                           
                           dss.ajaxAssyncRequestWithoutAnswer('/json/event/unsubscribe', {
                               subscriptionID : iSubscriptID,
                               name : 'sonos-controller-saved'
                           });
                       });
               },               
                
               prepareWhatTopPlayInfo : function(oResultObject, sSubPath) {
                 var sPlayInfo = "";
                 var nType = (parseInt("" + oResultObject.actionType,10));
                 switch(nType) {
                   case 0:
                      var nowAction = parseInt("" + oResultObject.nowAction,10);
                      if (nowAction == 0) { // single song/radio
                         var isRadio = JSON.parse(oResultObject.nowSingleIsRadio);
                         sPlayInfo = _("Song: ");
                         if (isRadio)
                           sPlayInfo = _("Radio: ");
                         if (oResultObject.nowSingleTitle != "")
                           sPlayInfo += oResultObject.nowSingleTitle;
                         if (oResultObject.nowSingleArtist != "")
                           sPlayInfo += " ("+oResultObject.nowSingleArtist+")";
                      }
                      else { // active song queue
                        sString = dss.ajaxSyncRequest('/json/property/query', {
                             'query' : '/scripts/sonos-controller/'+sSubPath+'/'+oResultObject.id+'/active-queue/*(*)/*(*)/*(*)/*(*)'
                         });
                        var result = Ext.JSON.decode(sString);
                        var arrayQueue = dss.parsePropertyQueryAnswer(result,[{name:'id', type:'simple'},
                                                                              {name:'title', type:'simple'},
                                                                              {name:'artist',type:'simple'}]); 
                        if (arrayQueue != null && arrayQueue.length > 0) {
                          var sTitle = "";
                          for(i=0;i<arrayQueue.length;i++) {   
                            if (i>2) {
                              sTitle += "..."; 
                              break;
                            }
                              
                            if (i>0)
                              sTitle += ", "; 
                            sTitle += arrayQueue[i].title;
                          }
                          sPlayInfo = sTitle;
                        }
                      }
                   break;
                   
                   case 1: // playlist
                     sPlayInfo = _("Playlist: ")+unescape(oResultObject.playListTitle);
                   break;
                  
                   case 2: // favorites
                     sPlayInfo = _("Favorites: ")+unescape(oResultObject.favoritesTitle);
                   break;

                   case 3: // Media library
                     sPlayInfo = _("Library: ")+unescape(oResultObject.mediaFileTitle);
                   break;
                   
                   case 4:    
                     sPlayInfo = _("Text voice: ")+unescape(oResultObject.t2Stext);
                   break;
                   
                   case 5: // command
                     var sCommand = "";
                     switch(parseInt("" + oResultObject.command,10)) {
                       case 1:
                         sCommand = _('Stop');
                       break;
                       case 2:
                         sCommand = _('Play');
                       break;
                       case 3:
                         sCommand = _('Pause');
                       break;
                       case 4:
                         sCommand = _('Mute');
                       break;
                       case 5:
                         sCommand = _('Unmute');
                       break;
                       case 6:
                         sCommand = _('Volume Up');
                       break;
                       case 7:
                         sCommand = _('Volume Down');
                       break;
                       
                     }
                     sPlayInfo = _("Command")+": "+sCommand;
                   break;
                 }
                 return sPlayInfo;
               },
                
               loadParameterPreset : function(grid) {
                grid.setStatus(_('Loading ...'));
                   dss.staticDataModel.initHLECache();
                   var sString = dss.ajaxSyncRequest('/json/property/query', {
                       'query' : '/scripts/sonos-controller/sonos-presets/*(*)/*(*)/*(*)/*(*)'
                   });           
                   var result = Ext.JSON.decode(sString);
                   var oResultFiltered = new Array();
                   oResultObject=dss.parsePropertyQueryAnswer(result,[{name:'id',type:'simple'},
                                                                      {name:'audioName',type:'simple'},
                                                                      {name:'roomID',type:'simple'},
                                                                      {name:'presetID',type:'simple'},
                                                                      {name:'presetName',type:'simple'},
                                                                      {name:'volume',type:'simple'},
                                                                      {name:'volumeSet',type:'simple'},
                                                                      {name:'volumeValue',type:'simple'},
                                                                      {name:'actionType',type:'simple'},
                                                                      {name:'nowAction',type:'simple'},
                                                                      {name:'nowSingleTitle',type:'simple'},
                                                                      {name:'nowSingleIsRadio',type:'simple'},
                                                                      {name:'nowSingleArtist',type:'simple'},
                                                                      {name:'nowSingleUrl',type:'simple'},
                                                                      {name:'playListTitle',type:'simple'},
                                                                      {name:'playListSonosID',type:'simple'},
                                                                      {name:'favoritesTitle',type:'simple'},
                                                                      {name:'favoritesSonosID',type:'simple'},
                                                                      {name:'command',type:'simple'},
                                                                      {name:'disabled', type:'simple'},
                                                                      {name:'predefined', type:'simple'},
                                                                      {name:'roomName',type:'simple'},
                                                                      {name:'triggers',type:'trigger'},
                                                                      {name:'active-queue',type:'simple'}]);    
                   if (oResultObject!=null) {
                       for (var iIndex=0;iIndex<oResultObject.length;iIndex++) {
                         if (oResultObject[iIndex].command != 6 && oResultObject[iIndex].command != 7) { // we skip volume up/down predefined preset
                           oResultObject[iIndex].disabled = JSON.parse(oResultObject[iIndex].disabled);
                           oResultObject[iIndex].predefined = JSON.parse(oResultObject[iIndex].predefined);
                           if (oResultObject[iIndex].audioName == null)
                             oResultObject[iIndex].audioName = "";
                           oResultObject[iIndex].roomName = "-";
                           if (oResultObject[iIndex].roomID > 0)
                             oResultObject[iIndex].roomName = dss.staticDataModel.getNameForZone(oResultObject[iIndex].roomID);
                           oResultObject[iIndex].volumeValue = "-";
                           if (JSON.parse(oResultObject[iIndex].volumeSet))
                             oResultObject[iIndex].volumeValue = _("Set volume to")+" "+oResultObject[iIndex].volume+" %";
                              
                           //oResultObject[iIndex].grouping=unescape(oResultObject[iIndex].roomName).split(' ')[0];
                           oResultObject[iIndex].grouping=oResultObject[iIndex].roomName;
                           oResultObject[iIndex].whatToPlayInfo = this.prepareWhatTopPlayInfo(oResultObject[iIndex], 'sonos-presets');
                           if (oResultObject[iIndex].predefined) {
                             var sValue = "";
                             var sGrouped = "";
                             var arrayScenes = new Array();
                             for (var yIndex=0;yIndex<oResultObject[iIndex].triggers.length;yIndex++) {
                               var trig = oResultObject[iIndex].triggers[yIndex];
                               
                               if (trig.zone == oResultObject[iIndex].roomID && arrayScenes.indexOf(trig.scene) == -1) {
                                 if (groupNamePresets.indexOf(trig.scene) > -1) {
                                   var sTmp = dss.staticDataModel.getNameForScene(trig.zone, trig.group, trig.scene);
                                   if (sGrouped == "")
                                     sGrouped = sTmp;
                                   else {
                                     sGrouped = sGrouped + "," + sTmp.split(" ")[1];
                                   }
                                 } 
                                 else {
                                   if (sValue != "") 
                                     sValue = sValue + "; "; 
                                   if (sGrouped != "") {
                                     sValue = sValue + sGrouped + "; "; 
                                     sGrouped = "";
                                   }
                                   sValue = sValue + dss.staticDataModel.getNameForScene(trig.zone, trig.group, trig.scene);
                                 }
                                 
                                 arrayScenes.push(trig.scene);
                               }
                             }
                             if (sGrouped != "") {
                               if (sValue != "") 
                                 sValue = sValue + "; "; 
                               sValue = sValue + sGrouped;
                             }
                               
                             oResultObject[iIndex].presetName = sValue; 
                           } 
                           else     {                                               
                             var nRoomID = parseInt(oResultObject[iIndex].roomID);
                             var nPresetID = parseInt(oResultObject[iIndex].presetID);
                             oResultObject[iIndex].presetName =  dss.staticDataModel.getDefaultNameForScene(nRoomID, 4, nPresetID); 
                           }
                           oResultFiltered.push(oResultObject[iIndex]);
                         }
                       }
                       grid.loadParameter(oResultFiltered);                                                
                   }
                   grid.setStatus(_('Ready'));
               },
               waitAndReloadPreset : function(grid) {            
                    grid.setStatus(_('Saving ...'));
                       var me = this;
                       
                       var iSubscriptID = Math.floor(Math.random() * 100000000000);
                       dss.ajaxSyncRequest('/json/event/subscribe', {
                           subscriptionID : iSubscriptID,
                           name : 'sonos-controller-saved'
                       });
                       dss.ajaxAssyncRequestWithoutAnswer('/json/event/get', {
                           subscriptionID : iSubscriptID,
                           timeout : 120 * 1000
                       }, function() {
                           me.loadParameterPreset(grid);
                           dss.ajaxAssyncRequestWithoutAnswer('/json/event/unsubscribe', {
                               subscriptionID : iSubscriptID,
                               name : 'sonos-controller-saved'
                           });
                       });
               },                

               loadParameterActivity : function(grid) {
                grid.setStatus(_('Loading ...'));
                
                   var sString = dss.ajaxSyncRequest('/json/property/query', {
                       'query' : '/scripts/sonos-controller/sonos-activities/*(*)/*(*)/*(*)/*(*)'
                   });           
                   var result = Ext.JSON.decode(sString);
                                     
                   oResultObject=dss.parsePropertyQueryAnswer(result,[{name:'id',type:'simple'},
                                                                      {name:'activityID',type:'simple'},
                                                                      {name:'activityName',type:'simple'},
                                                                      {name:'execRoomID',type:'simple'},
                                                                      {name:'volume',type:'simple'},
                                                                      {name:'volumeSet',type:'simple'},
                                                                      {name:'volumeValue',type:'simple'},
                                                                      {name:'actionType',type:'simple'},
                                                                      {name:'nowAction',type:'simple'},
                                                                      {name:'nowSingleTitle',type:'simple'},
                                                                      {name:'nowSingleIsRadio',type:'simple'},
                                                                      {name:'nowSingleArtist',type:'simple'},
                                                                      {name:'nowSingleUrl',type:'simple'},
                                                                      {name:'playListTitle',type:'simple'},
                                                                      {name:'playListSonosID',type:'simple'},
                                                                      {name:'favoritesTitle',type:'simple'},
                                                                      {name:'favoritesSonosID',type:'simple'},
                                                                      {name:'command',type:'simple'},
                                                                      {name:'disabled', type:'simple'},
                                                                      {name:'allRooms',type:'simple'},
                                                                      {name:'pickedRooms', type:'simple'},
                                                                      {name:'mediaFileTitle', type:'simple'},
                                                                      {name:'t2Stext', type:'simple'},
                                                                      {name:'triggers', type:'trigger'}]);    
                   if (oResultObject!=null) {
                       for (var iIndex=0;iIndex<oResultObject.length;iIndex++) {
                           oResultObject[iIndex].roomName= "-";
                           oResultObject[iIndex].disabled = JSON.parse(oResultObject[iIndex].disabled);
                    
                           oResultObject[iIndex].volumeValue = "-";
                           if (JSON.parse(oResultObject[iIndex].volumeSet))
                             oResultObject[iIndex].volumeValue = _("Set volume to")+" "+oResultObject[iIndex].volume+" %";
                           
                           oResultObject[iIndex].whatToPlayInfo = this.prepareWhatTopPlayInfo(oResultObject[iIndex], 'sonos-activities');
                           
                           var sRooms = _("All rooms");
                           if (oResultObject[iIndex].allRooms != "" && JSON.parse(oResultObject[iIndex].allRooms)==false) {
                             var tmpRooms = unescape(oResultObject[iIndex].pickedRooms).split(';');
                             sRooms = "";
                             for (var yIndex=0;yIndex<tmpRooms.length;yIndex++) { 
                                if (yIndex > 0) sRooms += ", ";
                                
                                var oValue=JSON.parse(dss.ajaxSyncRequest('/json/zone/getName',{id:tmpRooms[yIndex]}));
                                if (oValue!=null && oValue.result!=null) {
                                  if (oValue.result.name != '')
                                     sRooms += oValue.result.name;
                                  else
                                    sRooms += "#"+deviceData.ZoneID;
                                }                          
                             
                             }
                           }
                           oResultObject[iIndex].execRoomsName = sRooms;
                           
                           // remove undo scene triggers, that they are hidden from user (only when more than one trigger)
                           if (oResultObject[iIndex].triggers != null && oResultObject[iIndex].triggers.length>1) {
                             for (var yIndex=0;yIndex<oResultObject.length;yIndex++) {
                               var trigger = oResultObject[iIndex].triggers[yIndex];
                               if (trigger != null && trigger.type == "undo-zone-scene") {
                                 oResultObject[iIndex].triggers.splice(yIndex, 1);
                                 break;
                               }
                             }
                           }
                       }
                       grid.loadParameter(oResultObject);                                                
                   }
                   
                   grid.setStatus(_('Ready'));
               },
               waitAndReloadActivities : function(grid) {            
                    grid.setStatus(_('Saving ...'));
                       var me = this;
                       
                       var iSubscriptID = Math.floor(Math.random() * 100000000000);
                       dss.ajaxSyncRequest('/json/event/subscribe', {
                           subscriptionID : iSubscriptID,
                           name : 'sonos-controller-saved'
                       });
                       dss.ajaxAssyncRequestWithoutAnswer('/json/event/get', {
                           subscriptionID : iSubscriptID,
                           timeout : 120 * 1000
                       }, function(sValue) {
                           me.loadParameterActivity(grid);
                           dss.ajaxAssyncRequestWithoutAnswer('/json/event/unsubscribe', {
                               subscriptionID : iSubscriptID,
                               name : 'sonos-controller-saved'
                           });  
                           
                           if (sValue != "") {
                             var oValue=JSON.parse(sValue);
                             if (oValue.result.events[0] != null && oValue.result.events[0].properties.value != "") {
                               var sStoreMessage = "";
                               switch(parseInt("" + oValue.result.events[0].properties.value)) {
                                 case 79:
                                   sStoreMessage = _('The maximal number of created text messages per day was exceeded. File was not created.');
                                 break;
                                 
                                 case 8:
                                 case 9:
                                 case 30:
                                 case 98:
                                 case 99:
                                   sStoreMessage = _('Error creating Text To Speech file. File was not created.');
                                 break;
                               }
                               if (sStoreMessage != "")
                                 Ext.MessageBox.alert(_('Error while saving activity'), sStoreMessage, null);
                             }
                               
                           }
                       });
               }               
		       });

Ext.apply(Ext.data.SortTypes, {
    asPreset: function(oValue) {
        var nValue = 0;
        if (oValue.indexOf("-") == -1) {
          var aValue=oValue.split(" ");
          if (aValue != null && aValue.length>1)
            nValue = parseInt(""+aValue[1],10);
        }
        else
          nValue = 999; 
          
        return nValue;
      }        
    });

		       
Ext.onReady(function() {
  dss.buildUpLang(['locale/{languageSuffix}/sonos-controller.po']); 
  var sonosControllerApp = Ext.create('DSS.addon.SonosController');
  sonosControllerApp.initPage();
});

